\name{filterByProperty}
\alias{filterByProperty}
\title{filters a binary image according to statistics of the regions in it.}
\usage{
  filterByProperty(img, prop, THRESH = -1, imstat = NULL,
    foreground = 1, connectivity = 4, return.stats = FALSE,
    op = ">")
}
\arguments{
  \item{img}{Image to be filtered.}

  \item{prop}{String, one of "area", "perimeter",
  "rowcentre", "columncentre", "minellipse", "majellipse",
  "angleellipse", "MERtop", "MERbottom", "MERleft" or
  "MERright".}

  \item{THRESH}{optional. The threshold at which to filter
  the objects. If negative, the MEAN of the property will
  be used.}

  \item{imstat}{optional. If supplied, these statistics
  will be used rather than recalculating them.  Should be
  the output of \code{\link[Voir]{imstats}}.}

  \item{foreground}{the value of the foreground objects: 1
  or 0.}

  \item{connectivity}{connectivity with which to calculate
  statistics: 4 or 8.}

  \item{op}{string of a \code{op(a$prop,THRESH)} returning
  either TRUE or FALSE. Regions in the image for which
  \code{op(blob$prop,THRESH)} returns TRUE, are retained in
  the output.  Default ">", ie retains regions with
  \code{prop > THRESH}.}

  \item{return.stats}{Boolean, whether to return the
  calculated statistics from \code{\link[Voir]{imstats}}.}
}
\value{
  if \code{return.stats} is FALSE, a binary image that is
  TRUE for objects for which \code{op(a$prop,THRESH)} is
  TRUE.

  If \code{return.stats} is TRUE, a list: \describe{
  \item{stats}{A matrix containing the statistics of all
  the objects remaining in the image (column names "area",
  "perimeter", ...)} \item{image}{The binary image
  containing all the regions that satisfied
  \code{op(blob$prop,THRESH)==TRUE}.} \item{threshold}{The
  threshold used (helpful if the input THRESH was -1 and
  had to be calculated.} }
}
\description{
  filters a binary image according to statistics of the
  regions in it.
}
\seealso{
  \code{\link[Voir]{imstats}}

  Other morphology: \code{\link{filterBySize}}
}

